@@ -10,21 +10,22 @@ class GameConfig:
     def __init__(self, argv):
         self.app_dir = Path(os.path.abspath(os.path.dirname(__file__))).parent
 
-        self.data_dir = self.make_data_dir()
+        # any writable data like config.json should be copied in there
+        self.default_data_dir = self.get_default_data_path()
+
+        # If a dynamic data directory path is provided it will be used first
+        self.data_dir = self.find_or_make_data_dir()
 
         opts, _args = getopt(
-            argv, "hn:r:", ["game_name=", "resources_dir=", "help"])
+            argv, "n:r:", ["game_name=", "resources_dir="])
 
         self.arg_opts = opts
 
-        if self.get_opt("h", "help"):
-            self.print_help_and_exit()
-
         conf = self.get_conf()
 
         self.window_frame = conf.get("window_frame", True)
         self.window_fullscreen = conf.get("window_fullscreen", False)
-        self.default_small_window_size = (1000, 600)
+        self.default_small_window_size = (800, 550)
         self.window_size = tuple(
             conf.get("window_size", self.default_small_window_size))
 
@@ -48,7 +49,7 @@ class GameConfig:
         if self.no_resources:
             print("[WARNING] No game resources were found")
 
-        self.save_file = os.path.join(self.data_dir, "save.json")
+        self.save_file = os.path.join(self.default_data_dir, "save.json")
 
         self.translations_file = os.path.join(self.data_dir,
                                               "translations.json")
@@ -56,44 +57,32 @@ class GameConfig:
         self.disable_change_resources_dir = conf.get(
             "disable_change_resources_dir", False)
 
+        self.disable_light = conf.get("disable_light", False)
+
         self.create_default_config_file()
 
     def get_maybe_resources_in_data_dir(self) -> Optional[str]:
-        resources_in_data_dir_path = os.path.join(self.data_dir,
-                                                  "resources")
+        resources_in_data_dir_path = os.path.join(self.data_dir, "resources")
+
         if os.path.isdir(resources_in_data_dir_path):
             return str(resources_in_data_dir_path)
+
         return None
 
-    def print_help_and_exit(self):
-        lines = [
-            " _____",
-            "|   __|",
-            "|  |_           _____            _____     _",
-            "|   _|  /\\  |\\ |  |  /\\ |\\/|  /\\   |   |  /",
-            "|__|   /  \\ | \\|  |  \\/ |  | /  \\  |   |  \\_",
-            "",
-            "FANTOMATIC ENGINE  - Help",
-            "Syntax:",
-            "python -m fantomatic_engine -r [RESOURCES_DIRECTORY]"
-        ]
+    def get_default_data_path(self):
+        home_dir = os.path.abspath(Path.home())
+        return os.path.join(home_dir, ".fantomatic_data")
 
-        for l in lines:
-            print(l)
-
-        sys.exit()
-
-    def make_data_dir(self):
+    def find_or_make_data_dir(self):
         def find_data_dir(root) -> (str, bool):
-            data_dir = os.path.join(root, "fantomatic_data")
+            data_dir = os.path.join(root, ".fantomatic_data")
             return (data_dir, os.path.isdir(data_dir))
 
-        sys_root = os.path.abspath(os.sep)
-        exec_env = os.getenv("EXEC_DIR")
-
+        exec_dir = os.getenv("EXEC_DIR")
         data_dir_path = ""
 
-        for pth in (exec_env, sys_root, self.app_dir):
+        for pth in (exec_dir,  # Exec dir is provided so data dir could be inside it or be a virtual dir inside a onefile binary
+                    self.app_dir):  # a data directory can be provided in dev mode, in local source directory
             if pth:
                 (data_dir, exists) = find_data_dir(pth)
                 if exists:
@@ -101,8 +90,7 @@ class GameConfig:
                     break
 
         if not data_dir_path:
-            data_dir_path = os.path.join(
-                exec_env or self.app_dir, "fantomatic_data")
+            data_dir_path = self.default_data_dir
 
         if not os.path.isdir(data_dir_path):
             os.mkdir(data_dir_path)
@@ -110,30 +98,46 @@ class GameConfig:
         return data_dir_path
 
     def create_default_config_file(self):
-        conf_path = os.path.join(self.data_dir, "config.json")
-        if not self.conf_exists():
+        if not self.default_conf_exists():
             default_conf_data = {
                 "window_fullscreen": self.window_fullscreen,
                 "window_frame": self.window_frame,
                 "window_size": self.window_size,
-                "resources_dir": self.resources_dir,
+                "resources_dir": "",
+                "disable_change_resources_dir": self.disable_change_resources_dir,
+                "disable_light": self.disable_light,
                 "game_name": self.game_name,
                 "lang": self.lang
             }
-            self.write_conf(default_conf_data)  # Installation
+
+            self.write_conf(default_conf_data)
 
     def get_conf(self):
-        conf_path = os.path.join(self.data_dir, "config.json")
-        return json.load(open(conf_path)) if os.path.isfile(conf_path) else dict()
+        default_conf_path = os.path.join(self.default_data_dir, "config.json")
 
-    def conf_exists(self):
-        return os.path.isfile(os.path.join(self.data_dir, "config.json"))
+        if os.path.isfile(default_conf_path):
+            return json.load(open(default_conf_path, encoding="utf-8"))
+        else:
+            dyn_conf_path = os.path.join(self.data_dir, "config.json")
+
+            if os.path.isfile(dyn_conf_path):
+                return json.load(open(dyn_conf_path, encoding="utf-8"))
+            else:
+                return dict()
+
+    def default_conf_exists(self):
+        return os.path.isfile(os.path.join(self.default_data_dir, "config.json"))
 
     def translations_available(self):
         return os.path.isfile(self.translations_file)
 
     def write_conf(self, data: dict):
-        f = open(os.path.join(self.data_dir, "config.json"), "w")
+        if not os.path.isdir(self.default_data_dir):
+            os.mkdir(self.default_data_dir)
+
+        f = open(os.path.join(self.default_data_dir, "config.json"),
+                 "w", encoding="utf-8")
+
         f.write(json.dumps(data))
 
     def write_conf_key(self, key, value):
