@@ -65,7 +65,7 @@ class Game:
 
         self.light_halo: Optional[LightHalo] = LightHalo({
             "get_render_size": lambda: self.render.drawing_surface.get_size()
-        }, light_resource) if not light_resource.is_none else None
+        }, light_resource) if not config.disable_light and not light_resource.is_none else None
 
         self.interactions_manager = InteractionsManager({
             "get_scene": self.get_scene,
@@ -193,6 +193,22 @@ class Game:
                                  and self.config.window_fullscreen),
                 "secondary": True,
             },
+            {
+                "text": t("Disable light effect"),
+                "callback": lambda: self.handle_toggle_light_effect(True),
+                "cond": lambda: (self.menu_state == "config"
+                                 and not self.menu.browse_files
+                                 and not self.config.disable_light),
+                "secondary": True,
+            },
+            {
+                "text": t("Enable light effect"),
+                "callback": lambda: self.handle_toggle_light_effect(False),
+                "cond": lambda: (self.menu_state == "config"
+                                 and not self.menu.browse_files
+                                 and self.config.disable_light),
+                "secondary": True,
+            },
             {
                 "text": t("Select game data"),
                 "callback": self.handle_menu_browse_files,
@@ -343,6 +359,10 @@ class Game:
         self.config.write_conf_key("window_fullscreen", value)
         self.push_change_conf_notif()
 
+    def handle_toggle_light_effect(self, value):
+        self.config.write_conf_key("disable_light", value)
+        self.push_change_conf_notif()
+
     def handle_set_window_size(self, pseudo_value):
         sw = {
             "large": (-1, -1),
@@ -444,7 +464,7 @@ class Game:
         ) for it in self.menu_items_descriptors if it["cond"]()]
 
     def handle_skip_cinematic(self):
-        if self.scene.is_cinematic():
+        if self.scene.is_cinematic() and not self.scene.cinematic_disable_skip:
             if self.scene.background.play_once:
                 self.scene.background.skip()
             else:
