@@ -8,7 +8,7 @@ class Translator:
         self.translations = self.load_translations(conf)
 
     def load_translations(self, conf: GameConfig) -> dict:
-        return (json.load(open(conf.translations_file)).get(self.lang, dict())
+        return (json.load(open(conf.translations_file, encoding="utf-8")).get(self.lang, dict())
                 if conf.translations_available()
                 else dict())
 
