@@ -3,7 +3,7 @@ import pygame
 
 class LoadingWindow:
     def __init__(self, text: str):
-        self.font = pygame.font.SysFont("sans", 18)
+        self.font = pygame.font.SysFont("mono", 18)
         self.font.set_bold(True)
         self.text = text
         self.text_dots = ""
