@@ -4,7 +4,7 @@ from functools import reduce
 from typing import Optional, List, Set, Tuple
 from .. import Sprite
 from ..image import Animation
-from ..vectors import vec2
+from ..vectors import vec2, vec_is_nul
 from ..shapes import Rectangle
 from ..dialog_box import DialogBox
 from .camera import Camera
@@ -15,7 +15,6 @@ from ..feedback import Feedback
 
 class Render:
     def __init__(self, rendering_surface: pygame.Surface):
-
         # default, will be function of background image
         self.drawing_surface = pygame.Surface((800, 800))
 
@@ -48,18 +47,34 @@ class Render:
             "get_bounds": lambda: self.drawing_surface.get_rect()
         })
 
-        font_path = os.getenv("FONT_PATH")
+        self.font_cta = pygame.font.SysFont("mono", 30, True)
+        self.font_dialog = pygame.font.SysFont("mono", 20)
+        self.font_small = pygame.font.SysFont("mono", 16)
 
-        self.font_cta = pygame.font.Font(font_path, 35)
-        self.font_dialog = pygame.font.Font(font_path, 25)
-        self.font_small = pygame.font.Font(font_path, 16)
+        self.font_menu = pygame.font.SysFont("mono", 40, True)
+        self.font_menu_secondary = pygame.font.SysFont("mono", 30)
+        self.font_menu_read_only = pygame.font.SysFont("mono", 25)
+        self.font_menu_small = pygame.font.SysFont("mono", 20)
 
-        self.font_menu = pygame.font.Font(font_path, 40)
-        self.font_menu_secondary = pygame.font.Font(font_path, 30)
-        self.font_menu_read_only = pygame.font.Font(font_path, 25)
-        self.font_menu_small = pygame.font.Font(font_path, 20)
-        self.font_menu_file_explorer_dirname = pygame.font.Font(font_path, 20)
-        self.font_menu_notification = pygame.font.Font(font_path, 25)
+        self.fonts = {
+            "regular": {
+                "cta": pygame.font.SysFont("mono", 30, True),
+                "dialog": pygame.font.SysFont("mono", 20),
+                "small": pygame.font.SysFont("mono", 16),
+                "menu": pygame.font.SysFont("mono", 40, True),
+                "menu_secondary": pygame.font.SysFont("mono", 30),
+                "menu_read_only": pygame.font.SysFont("mono", 25),
+                "menu_small": pygame.font.SysFont("mono", 20),
+            },
+            "larger": {
+                "cta": pygame.font.SysFont("sans", 45, True),
+                "dialog": pygame.font.SysFont("sans", 25),
+                "small": pygame.font.SysFont("sans", 24),
+            }
+        }
+
+        self.font_menu_file_explorer_dirname = pygame.font.SysFont("mono", 20)
+        self.font_menu_notification = pygame.font.SysFont("mono", 25)
 
         self.prev_left = 0
 
@@ -81,6 +96,7 @@ class Render:
                   dialog_box: Optional[DialogBox],
                   inventory: Optional[Set[Sprite]],
                   feedback: Optional[Feedback]):
+
         rendering_opts = scene_background.rendering_options or dict()
 
         if self.last_drawn_background != scene_background:
@@ -116,12 +132,12 @@ class Render:
             self.__draw_light(light_surface)
 
         if dialog_box:
-            self.__draw_dialog(dialog_box)
+            self.__draw_dialog(dialog_box, rendering_opts)
 
         if cta and not (dialog_box
                         and dialog_box.open
                         and not dialog_box.stream_is_complete()):
-            self.__draw_cta(cta)
+            self.__draw_cta(cta, rendering_opts)
 
         if inventory and len(inventory) > 0:
             self.__draw_inventory(inventory)
@@ -139,6 +155,170 @@ class Render:
         self.drawing_surface.blit(surf, (0, 0))
         self.__render()
 
+    def __draw_background(self, anim):
+        rendering_opts = anim.rendering_options or dict()
+        self.x_rendering_offset = (self.rendering_surface.get_size()
+                                   [0] - self.render_size[0]) / 2 if rendering_opts.get("center_x") else 0
+
+        self.drawing_surface.blit(anim.get_frame(), self.drawing_pos_offset)
+
+    def __draw_sprites(self,  sprites):
+        sprites.sort(key=lambda s: s.z_index)
+
+        self.drawing_surface.blits([(
+            sprite.animation.get_frame(),
+            sprite.position + self.drawing_pos_offset
+        ) for sprite in sprites])
+
+    def __draw_light(self, light_surface):
+        self.drawing_surface.blit(light_surface,
+                                  (0, 0),
+                                  (0, 0, self.drawing_size[0], self.drawing_size[1]))
+
+    def __draw_cta(self, cta: str, background_rendering_options):
+        font_key = ("regular"
+                    if not background_rendering_options.get("use_max_height")
+                    else "larger")
+
+        font_cta = self.fonts[font_key]["cta"]
+        font_small = self.fonts[font_key]["small"]
+
+        line_height = font_cta.get_height()
+        hint = "[ touche espace ]"
+
+        cta_text_size = font_cta.size(cta)
+        hint_text_size = font_small.size(hint)
+
+        cta_size = vec2(max(cta_text_size[0], hint_text_size[0]) +
+                        40, cta_text_size[1] + hint_text_size[1] + 30)
+
+        x_pos_cta = (cta_size[0] - cta_text_size[0]) / 2
+        y_pos_cta = (cta_size[1] - (hint_text_size[1] + cta_text_size[1])) / 2
+        x_pos_hint = (cta_size[0] - hint_text_size[0]) / 2
+
+        cta_surf = pygame.Surface(cta_size, pygame.SRCALPHA)
+        cta_surf.fill((0, 0, 0, 127))
+
+        cta_surf.blit(font_cta.render(
+            cta, False, (255, 255, 255)), (x_pos_cta, y_pos_cta))
+
+        cta_surf.blit(font_small.render(
+            hint, False, (255, 255, 255)), (x_pos_hint, y_pos_cta + line_height))
+
+        unscaled_screen_size = self.screen_size / self.scale_factor
+
+        if not vec_is_nul(self.drawing_pos_offset):
+            base_cta_pos = unscaled_screen_size / 2
+        else:
+            base_cta_pos = vec2(
+                self.drawing_size[0], unscaled_screen_size[1]) / 2
+
+        cta_pos = base_cta_pos - (cta_size / 2)
+
+        self.drawing_surface.blit(cta_surf, cta_pos)
+
+    def __draw_dialog(self, dialog: DialogBox, background_rendering_options):
+        font_key = ("regular"
+                    if not background_rendering_options.get("use_max_height")
+                    else "larger")
+
+        font_dialog = self.fonts[font_key]["dialog"]
+
+        stream = dialog.get_text_stream()
+        line_height = font_dialog.get_height()
+
+        unscaled_render_size = self.render_size / self.scale_factor
+        unscaled_screen_size = self.screen_size / self.scale_factor
+
+        total_text_height = len(dialog.text.split("\n")) * line_height
+
+        margin = 50
+        padding_x = 40
+        padding_y = 20
+
+        image_size = (100, 100) if dialog.image else (0, 0)
+
+        dialog_box_height = (max(image_size[1], total_text_height)
+                             + (2*padding_y if dialog.image
+                                else total_text_height + 2*padding_y))
+
+        dialog_box_size = (unscaled_render_size[0] - margin * 2,
+                           dialog_box_height)
+
+        dialog_box_pos = (margin,
+                          unscaled_screen_size[1] - margin - dialog_box_size[1])
+
+        text_pos_x = (padding_x +
+                      ((image_size[0] + 20) if dialog.image else 0))
+
+        text_pos_y = (dialog_box_size[1] - total_text_height) / 2
+
+        dialog_surf = pygame.Surface(dialog_box_size, pygame.SRCALPHA)
+
+        dialog_surf.fill((200, 200, 200, 150))
+
+        for (i, line) in enumerate(stream.split("\n")):
+            text_surf = font_dialog.render(line, False, (20, 20, 20))
+            dialog_surf.blit(text_surf, (text_pos_x,
+                                         text_pos_y + i * line_height))
+
+        if dialog.image:
+            image_surf = pygame.transform.scale(
+                dialog.image.get_frame(),
+                image_size)
+
+            dialog_surf.blit(
+                dialog.image.get_frame(),
+                (padding_x, padding_y, *image_size))
+
+        self.drawing_surface.blit(dialog_surf, dialog_box_pos)
+
+    def __draw_inventory(self, inventory: Set[Sprite]):
+        icon_size = vec2(50, 50) / self.scale_factor
+        margin = 10
+        panel_width = len(inventory) * (icon_size[0] + margin)
+        panel_height = icon_size[1]
+        surf = pygame.Surface((panel_width, panel_height), pygame.SRCALPHA)
+        x = 0
+
+        items = sorted(inventory, key=lambda i: i.inventory_position)
+
+        for (i, item) in enumerate(items):
+            image = item.animation.get_frame()
+            im_size = vec2(*image.get_size())
+            icon = pygame.transform.scale(image,
+                                          im_size * (icon_size[0] / im_size[0]))
+            surf.blit(icon,
+                      (x + i*(icon_size[0] + margin),
+                       (panel_height - icon.get_size()[1]) / 2))
+
+        self.drawing_surface.blit(surf, (5, 5))
+
+    def __draw_feedback(self, feedback: dict):
+        unscaled_screen_size = self.screen_size / self.scale_factor
+        surf = pygame.Surface(unscaled_screen_size, pygame.SRCALPHA)
+        surf.fill((0, 0, 0, 127))
+        img = feedback.image.get_frame()
+        base_size = vec2(*img.get_size())
+        render_height = unscaled_screen_size[1] / 2
+        render_img = pygame.transform.scale(img,
+                                            base_size * (render_height / base_size[1]))
+
+        render_size = render_img.get_size()
+
+        img_pos = ((unscaled_screen_size[0] - render_size[0]) / 2,
+                   (unscaled_screen_size[1] - render_size[1]) / 2)
+
+        surf.blit(render_img, img_pos)
+
+        text_surf = self.font_cta.render(
+            feedback.message, False, (200, 200, 200))
+
+        surf.blit(text_surf, ((unscaled_screen_size[0] - text_surf.get_size()[0]) / 2,
+                              img_pos[1] + render_size[1] + 20))
+
+        self.drawing_surface.blit(surf, (0, 0))
+
     def draw_menu(self, menu: Menu, notification: str):
         # Menu is drawn directly at screen size in order to prevent the font from being pixelated
         self.menu_drawing_surface.fill((0, 0, 0, 255))
@@ -276,153 +456,6 @@ class Render:
 
         self.__render(True)
 
-    def __draw_background(self, anim):
-        rendering_opts = anim.rendering_options or dict()
-        self.x_rendering_offset = (self.rendering_surface.get_size()
-                                   [0] - self.render_size[0]) / 2 if rendering_opts.get("center_x") else 0
-
-        self.drawing_surface.blit(anim.get_frame(), self.drawing_pos_offset)
-
-    def __draw_sprites(self,  sprites):
-        sprites.sort(key=lambda s: s.z_index)
-
-        self.drawing_surface.blits([(
-            sprite.animation.get_frame(),
-            sprite.position + self.drawing_pos_offset
-        ) for sprite in sprites])
-
-    def __draw_light(self, light_surface):
-        self.drawing_surface.blit(light_surface,
-                                  (0, 0),
-                                  (0, 0, self.drawing_size[0], self.drawing_size[1]))
-
-    def __draw_cta(self, cta: str):
-        line_height = self.font_cta.get_height()
-        hint = "[ touche espace ]"
-        cta_text_size = self.font_cta.size(cta)
-        hint_text_size = self.font_small.size(hint)
-
-        cta_size = (max(cta_text_size[0], hint_text_size[0]) +
-                    40, cta_text_size[1] + hint_text_size[1] + 30)
-
-        x_pos_cta = (cta_size[0] - cta_text_size[0]) / 2
-        y_pos_cta = (cta_size[1] - (hint_text_size[1] + cta_text_size[1])) / 2
-        x_pos_hint = (cta_size[0] - hint_text_size[0]) / 2
-
-        cta_surf = pygame.Surface(cta_size, pygame.SRCALPHA)
-        cta_surf.fill((0, 0, 0, 127))
-
-        cta_surf.blit(self.font_cta.render(
-            cta, False, (255, 255, 255)), (x_pos_cta, y_pos_cta))
-
-        cta_surf.blit(self.font_small.render(
-            hint, False, (255, 255, 255)), (x_pos_hint, y_pos_cta + line_height))
-
-        unscaled_render_size = self.render_size / self.scale_factor
-        unscaled_screen_size = self.screen_size / self.scale_factor
-
-        cta_pos = (
-            unscaled_render_size[0] / 2 - cta_size[0] / 2,
-            unscaled_screen_size[1] / 2 - cta_size[1] / 2
-        )
-
-        self.drawing_surface.blit(cta_surf, cta_pos)
-
-    def __draw_dialog(self, dialog: DialogBox):
-        stream = dialog.get_text_stream()
-        line_height = self.font_dialog.get_height()
-
-        unscaled_render_size = self.render_size / self.scale_factor
-        unscaled_screen_size = self.screen_size / self.scale_factor
-
-        total_text_height = len(dialog.text.split("\n")) * line_height
-
-        margin = 50
-        padding_x = 40
-        padding_y = 20
-
-        image_size = (100, 100) if dialog.image else (0, 0)
-
-        dialog_box_height = (max(image_size[1], total_text_height)
-                             + (2*padding_y if dialog.image
-                                else total_text_height + 2*padding_y))
-
-        dialog_box_size = (
-            unscaled_render_size[0] - margin * 2, dialog_box_height)
-
-        dialog_box_pos = (margin,
-                          unscaled_screen_size[1] - margin - dialog_box_size[1])
-
-        text_pos_x = (padding_x +
-                      ((image_size[0] + 20) if dialog.image else 0))
-
-        text_pos_y = (dialog_box_size[1] - total_text_height) / 2
-
-        dialog_surf = pygame.Surface(dialog_box_size, pygame.SRCALPHA)
-
-        dialog_surf.fill((200, 200, 200, 150))
-
-        for (i, line) in enumerate(stream.split("\n")):
-            text_surf = self.font_dialog.render(line, False, (20, 20, 20))
-            dialog_surf.blit(text_surf, (text_pos_x,
-                                         text_pos_y + i * line_height))
-
-        if dialog.image:
-            image_surf = pygame.transform.scale(
-                dialog.image.get_frame(),
-                image_size)
-            dialog_surf.blit(
-                dialog.image.get_frame(),
-                (padding_x, padding_y, *image_size))
-
-        self.drawing_surface.blit(dialog_surf, dialog_box_pos)
-
-    def __draw_inventory(self, inventory: Set[Sprite]):
-        icon_size = vec2(50, 50) / self.scale_factor
-        margin = 10
-        panel_width = len(inventory) * (icon_size[0] + margin)
-        panel_height = icon_size[1]
-        surf = pygame.Surface((panel_width, panel_height), pygame.SRCALPHA)
-        x = 0
-
-        items = sorted(inventory, key=lambda i: i.inventory_position)
-
-        for (i, item) in enumerate(items):
-            image = item.animation.get_frame()
-            im_size = vec2(*image.get_size())
-            icon = pygame.transform.scale(image,
-                                          im_size * (icon_size[0] / im_size[0]))
-            surf.blit(icon,
-                      (x + i*(icon_size[0] + margin),
-                       (panel_height - icon.get_size()[1]) / 2))
-
-        self.drawing_surface.blit(surf, (5, 5))
-
-    def __draw_feedback(self, feedback: dict):
-        unscaled_screen_size = self.screen_size / self.scale_factor
-        surf = pygame.Surface(unscaled_screen_size, pygame.SRCALPHA)
-        surf.fill((0, 0, 0, 127))
-        img = feedback.image.get_frame()
-        base_size = vec2(*img.get_size())
-        render_height = unscaled_screen_size[1] / 2
-        render_img = pygame.transform.scale(img,
-                                            base_size * (render_height / base_size[1]))
-
-        render_size = render_img.get_size()
-
-        img_pos = ((unscaled_screen_size[0] - render_size[0]) / 2,
-                   (unscaled_screen_size[1] - render_size[1]) / 2)
-
-        surf.blit(render_img, img_pos)
-
-        text_surf = self.font_cta.render(
-            feedback.message, False, (200, 200, 200))
-
-        surf.blit(text_surf, ((unscaled_screen_size[0] - text_surf.get_size()[0]) / 2,
-                              img_pos[1] + render_size[1] + 20))
-
-        self.drawing_surface.blit(surf, (0, 0))
-
     def __render(self, menu=False):
         if menu:
             self.rendering_surface.blit(self.menu_drawing_surface, (0, 0))
