@@ -12,10 +12,7 @@ def show_loading(state, loading_window):
 
 
 def run_game(argv):
-    os.environ["SDL_VIDEO_WINDOW_POS"] = "50,50"
-
-    os.environ["FONT_PATH"] = os.path.join(
-        os.path.dirname(__file__), "PerfectDosVGAWin.ttf")
+    os.environ["SDL_VIDEO_WINDOW_POS"] = "40,40"
 
     pygame.init()
 
